import 'package:easy_localization/easy_localization.dart';
import 'package:fl_chart/fl_chart.dart';
import 'package:flutter/material.dart';

import '../../../config/app_colors.dart';
import '../../../utils/color_extensions.dart';

class CustomLineChart extends StatelessWidget {
  CustomLineChart({super.key});

  final double chartHeight = 120.0;

  @override
  Widget build(BuildContext context) {
    return Container(
      child: SizedBox(
        height: this.chartHeight,
      ),
    );
  }

  LinearGradient getGradient(Color baseColor) {
    return LinearGradient(
      begin: Alignment.topCenter,
      end: Alignment.bottomCenter,
      colors: <Color>[
        baseColor.lighten(30),
        baseColor,
        baseColor.darken(30),
      ],
      tileMode: TileMode.mirror,
    );
  }

  FlBorderData getBorderData() {
    return FlBorderData(
      show: true,
      border: Border.all(
        color: AppColors.borderColor,
        width: 2,
      ),
    );
  }

  FlGridData getGridData() {
    return const FlGridData(
      show: true,
      drawHorizontalLine: true,
      drawVerticalLine: false,
    );
  }

  Widget getVerticalTitlesWidget(double value, TitleMeta meta) {
    return SideTitleWidget(
      axisSide: meta.axisSide,
      space: 4,
      child: Text(
        value.toInt().toString(),
        style: const TextStyle(
          color: AppColors.mainTextColor1,
          fontSize: 12,
        ),
      ),
    );
  }

  Widget getHorizontalTitlesWidget(double value, TitleMeta meta) {
    final DateFormat formatter = DateFormat('dd/MM');

    final DateTime date = DateTime.fromMillisecondsSinceEpoch(value.toInt());
    final String text = formatter.format(date);

    return SideTitleWidget(
      axisSide: meta.axisSide,
      space: 4,
      child: RotationTransition(
        turns: new AlwaysStoppedAnimation(-30 / 360),
        child: Text(
          text,
          style: const TextStyle(
            color: AppColors.mainTextColor1,
            fontSize: 11,
          ),
        ),
      ),
    );
  }

  LineTouchData getLineTouchDataEclecticism() {
    return LineTouchData(
      handleBuiltInTouches: true,
      touchTooltipData: LineTouchTooltipData(
        tooltipBgColor: Colors.transparent,
        tooltipPadding: EdgeInsets.all(8),
        tooltipMargin: 2,
        getTooltipItems: (List<LineBarSpot> touchedSpots) {
          return touchedSpots.map((LineBarSpot touchedSpot) {
            final textStyle = TextStyle(
              color: AppColors.mainTextColor2,
              fontWeight: FontWeight.bold,
              fontSize: 10,
            );
            return LineTooltipItem(
              touchedSpot.y.toString(),
              textStyle,
            );
          }).toList();
        },
      ),
    );
  }
}
