import 'package:flutter/material.dart';
import 'package:fl_chart/fl_chart.dart';

import '../../../config/app_colors.dart';
import '../../../models/counts_by_hour.dart';
import '../../../ui/widgets/charts/custom_bar_chart.dart';
import '../../../utils/color_extensions.dart';

class CountsByHourCardContentChart extends CustomBarChart {
  final CountsByHourData chartData;

  CountsByHourCardContentChart({super.key, required this.chartData});

  @override
  Widget build(BuildContext context) {
    return Container(
      height: this.chartHeight,
      child: LayoutBuilder(builder: (context, constraints) {
        return getBarChart(
          barWidth: this.getBarWidth(constraints.maxWidth, this.chartData.data.keys.length),
          backgroundColor: Theme.of(context).colorScheme.onSurface,
        );
      }),
    );
  }

  double getMaxCountsValue() {
    double maxValue = 0;

    this.chartData.data.keys.forEach((key) {
      double? counts = this.chartData.data[key];
      if (counts != null) {
        if (counts > maxValue) {
          maxValue = counts;
        }
      }
    });

    return maxValue;
  }

  List<BarChartGroupData> getDataCounts(double barWidth) {
    List<BarChartGroupData> data = [];

    final barColor = AppColors.contentColorCyan.darken(30);

    this.chartData.data.keys.forEach((day) {
      final double? counts = this.chartData.data[day];

      if (counts != null) {
        data.add(getBarItem(
          x: day,
          value: counts,
          barColor: barColor,
          barWidth: barWidth,
        ));
      }
    });

    return data;
  }

  Widget getHorizontalTitlesWidget(double value, TitleMeta meta) {
    String text = '';

    if (value % 4 == 0 || value == 23) {
      text = value.toInt().toString().padLeft(2, '0');
    }

    return SideTitleWidget(
      axisSide: meta.axisSide,
      space: 2,
      child: Text(
        text,
        style: const TextStyle(
          color: AppColors.mainTextColor1,
          fontSize: 11,
        ),
      ),
    );
  }
}
