import 'package:flutter/material.dart';
import 'package:fl_chart/fl_chart.dart';

import '../../../config/app_colors.dart';
import '../../../models/timeline.dart';
import '../../../ui/widgets/charts/custom_line_chart.dart';
import '../../../utils/color_extensions.dart';

class ChartTimelineEclecticism extends CustomLineChart {
  final TimelineData chartData;

  ChartTimelineEclecticism({super.key, required this.chartData});

  @override
  Widget build(BuildContext context) {
    return Container(
      height: this.chartHeight,
      child: LineChart(
        LineChartData(
          lineBarsData: getDataEclecticism(),
          backgroundColor: Theme.of(context).colorScheme.onSurface,
          borderData: getBorderData(),
          gridData: getGridData(),
          titlesData: getTitlesData(),
          lineTouchData: getLineTouchDataEclecticism(),
          maxY: 100,
          minY: 0,
        ),
        duration: const Duration(milliseconds: 250),
      ),
    );
  }

  List<LineChartBarData> getDataEclecticism() {
    List<FlSpot> spots = [];

    this.chartData.data.keys.forEach((element) {
      TimelineDataValue? value = this.chartData.data[element];
      if (value != null) {
        final double date = DateTime.parse(element).millisecondsSinceEpoch.toDouble();
        final double eclecticism = value.eclecticism.toDouble();

        spots.add(FlSpot(date, eclecticism));
      }
    });

    final baseColor = AppColors.contentColorCyan;
    final gradient = getGradient(baseColor);
    final borderColor = baseColor.darken(20);

    return [
      LineChartBarData(
        isCurved: true,
        color: borderColor,
        barWidth: 3,
        isStrokeCapRound: false,
        dotData: const FlDotData(show: false),
        belowBarData: BarAreaData(
          show: true,
          color: baseColor,
          gradient: gradient,
        ),
        spots: spots,
      ),
    ];
  }

  FlTitlesData getTitlesData() {
    const AxisTitles none = const AxisTitles(
      sideTitles: SideTitles(showTitles: false),
    );

    final AxisTitles verticalTitles = AxisTitles(
      sideTitles: SideTitles(
        showTitles: true,
        reservedSize: 30,
        getTitlesWidget: getVerticalTitlesWidget,
        interval: 25,
      ),
    );
    final AxisTitles horizontalTitles = AxisTitles(
      sideTitles: SideTitles(
        showTitles: true,
        reservedSize: 20,
        getTitlesWidget: getHorizontalTitlesWidget,
      ),
    );

    return FlTitlesData(
      show: true,
      bottomTitles: horizontalTitles,
      leftTitles: verticalTitles,
      topTitles: none,
      rightTitles: verticalTitles,
    );
  }
}
